---
title: <span class="badge object-type-scalar"></span> Microseconds
---
# <span class="badge object-type-scalar"></span> Microseconds

Time: microseconds (µs)

## Definition

```python
# Time: microseconds (µs)
Microseconds: typing.Literal["µs"] = "µs"
```
